@@ -24,8 +24,8 @@ struct _Node {
 GtkTreePath *
 gconf_tree_model_get_tree_path_from_gconf_path (GConfTreeModel *tree_model, const char *key)
 {
-	GtkTreePath *path;
-	GtkTreeIter iter, child_iter;
+	GtkTreePath *path = NULL;
+	GtkTreeIter iter, child_iter, found_iter;
 	gchar *tmp_str;
 	gchar **key_array;
 	int i;
@@ -52,10 +52,8 @@ gconf_tree_model_get_tree_path_from_gconf_path (GConfTreeModel *tree_model, cons
 		 * code isn't handling those incomplete levels yet (that
 		 * needs some current level/gconf directory comparing code)
 		 */
-		if (!gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_model), &child_iter, &iter)) {
-			g_strfreev (key_array);
-			return NULL;
-		}
+		if (!gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_model), &child_iter, &iter))
+			break;
 
 		found = FALSE;
 		do {
@@ -64,19 +62,20 @@ gconf_tree_model_get_tree_path_from_gconf_path (GConfTreeModel *tree_model, cons
 					    -1);
 
 			if (strcmp (tmp_str, key_array[i]) == 0) {
+				found_iter = child_iter;
 				found = TRUE;
 				break;
 			}
 		} while (gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_model), &child_iter));
 
-		if (!found) {
-			g_strfreev (key_array);
-			return NULL;
-		}
+		if (!found)
+			break;
 		iter = child_iter;
 	}
 
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_model), &child_iter);
+	path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_model), &found_iter);
+
+	g_strfreev (key_array);
 
 	return path;
 }
